@@ -405,8 +405,17 @@ void show_input(GtkTreeView * treeview, int which)
     }
     g_free(path);
     gtk_widget_grab_focus((GtkWidget *) entry);
-    gtk_editable_select_region (GTK_EDITABLE (entry), 0, 0);
-    gtk_editable_set_position(GTK_EDITABLE (entry),-1);
+    /* these will preselect */
+    
+    if (which == NEW_INPUT || which == SYMLINK_INPUT ||
+	which ==  RUN_INPUT || which == RUN_DOUBLE_CLICK ||
+        which == PRINT_INPUT){
+      gtk_editable_set_position(GTK_EDITABLE (entry),0);
+      gtk_editable_select_region (GTK_EDITABLE (entry), 0, -1);
+    } else {
+      gtk_editable_select_region (GTK_EDITABLE (entry), 0, 0);
+      gtk_editable_set_position(GTK_EDITABLE (entry),-1);
+    }
     if (which==WORKDIR_INPUT) gtk_main();
 }
 
