@@ -682,6 +682,7 @@ static gboolean treeview_key(GtkWidget *w,
 	    (event->keyval >= GDK_a && event->keyval <= GDK_z) )
 	{
 	    char c;
+	    int emergency=0;
 	    gchar *a=NULL,*b=NULL;
 	    if (event->keyval >= GDK_a && event->keyval <= GDK_z)
 		c=event->keyval - GDK_a + 'a';
@@ -721,7 +722,7 @@ static gboolean treeview_key(GtkWidget *w,
 		}
 	
     		gtk_tree_model_get(treemodel, &iter2, NAME_COLUMN, &f, ENTRY_COLUMN, &en, -1);
-		
+		emergency++;
 		if (!f) continue;
 		/*printf("DBG:(%s) %d==%d\n",en->path,*f,c);*/
 		if (*f == c){
@@ -735,9 +736,14 @@ static gboolean treeview_key(GtkWidget *w,
 		} 
 		g_free(b);
 		b=gtk_tree_path_to_string(ipath);
-	    } while (strcmp(a,b));
+	    } while (strcmp(a,b) || emergency<13000);
 	    g_free(a);
 	    g_free(b);
+	    if (emergency >= 13000){
+		    /* this should probably never happen */
+		    print_diagnostics(treeview,"xf_ERROR_ICON",
+			strerror(ETIMEDOUT),"\n",NULL);
+	    }
 	    
     	    if (ipath) gtk_tree_path_free(ipath);
 	    return FALSE;
